@@ -1,18 +1,21 @@
 # !/usr/bin/env python3
-# encoding: utf-8
+# -*- coding: utf-8 -*-
 from logging import getLogger, Formatter, StreamHandler, FileHandler
 from os import makedirs, PathLike, getcwd, sep
 from os.path import exists, join, isdir
 from time import strftime, localtime
 from functools import wraps
-from colorama import init as color_init
 from typing import Union, List
 from re import split as re_split
-
-color_init(strip=False)
+try:
+    from colorama import init as color_init
+    color_init(strip=False)
+except (ImportError, ModuleNotFoundError):
+    from os import system
+    system('')
 
 
-def _check_date(func):
+def _log_wrapper(func):
     @wraps(func)
     def wrap(self, msg):
         str_time = strftime('%m-%d', localtime())
@@ -105,23 +108,36 @@ class Logger:
         self._cmdh.setFormatter(self._Stream_Formatter(formats, date_format))
         self._logh.setFormatter(Formatter(self._format, self._date_format))
 
+    @staticmethod
+    def disable_logger(loggers: Union[str, List[str]]):
+        """
+        用于disable禁用logger
+
+        :param loggers: 需要禁用的logger名称或名称列
+        """
+        if isinstance(loggers, list):
+            for items in loggers:
+                getLogger(items).disabled = True
+        else:
+            getLogger(loggers).disabled = True
+
     def _new_logh(self, str_time):
         self._logh = FileHandler(join(self.file_path, f'{str_time}.log'), encoding='utf-8')
         self._logh.setFormatter(Formatter(self._format, self._date_format))
         self._logger.addHandler(self._logh)
 
-    @_check_date
+    @_log_wrapper
     def debug(self, msg):
         self._logger.debug(msg)
 
-    @_check_date
+    @_log_wrapper
     def info(self, msg):
         self._logger.info(msg)
 
-    @_check_date
+    @_log_wrapper
     def warning(self, msg):
         self._logger.warning(msg)
 
-    @_check_date
+    @_log_wrapper
     def error(self, msg):
         self._logger.error(msg)
