@@ -1,5 +1,9 @@
 # !/usr/bin/env python3
-# encoding: utf-8
+# -*- coding: utf-8 -*-
+from typing import List
+from ._utils import event_class
+
+
 class Model:
     """
     使用此Model库可用作验证事件数据的准确性，目前可用的模型如下：
@@ -7,7 +11,7 @@ class Model:
     GUILDS - 频道事件
     GUILD_MEMBERS -
     """
-    class GUILDS:
+    class GUILDS(event_class):
         """
         频道事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -17,7 +21,7 @@ class Model:
 
         .. seealso::
             其子字段数据可参阅：
-            https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#62777ff1e5cc8b00129a9f2d
+            https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#guilds
         """
         description: str
         icon: str
@@ -31,7 +35,7 @@ class Model:
         t: str
         event_id: str
 
-    class CHANNELS:
+    class CHANNELS(event_class):
         """
         子频道事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -41,7 +45,7 @@ class Model:
 
         .. seealso::
             其子字段数据可参阅：
-            https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#62ac93d90f38ae0012fb0079
+            https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#channels-sdkv2-2-4
         """
         application_id: str
         guild_id: str
@@ -59,7 +63,7 @@ class Model:
         t: str
         event_id: str
 
-    class GUILD_MEMBERS:
+    class GUILD_MEMBERS(event_class):
         """
         频道成员事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -69,7 +73,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#627795cdc4773b0012899ec4
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#guild-members
         """
         class user:
             avatar: str
@@ -81,11 +85,11 @@ class Model:
         joined_at: str
         nick: str
         op_user_id: str
-        roles: list[str]
+        roles: List[str]
         t: str
         event_id: str
 
-    class MESSAGE:
+    class MESSAGE(event_class):
         """
         消息事件的数据模，可从t字段判断具体事件，其中包含：
 
@@ -97,7 +101,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#627797dfc4773b0012899ec7
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#message
         """
         class __MsgMentions:
             avatar: str
@@ -126,14 +130,14 @@ class Model:
         class member:
             joined_at: str
             nick: str
-            roles: list[str]
+            roles: List[str]
 
         channel_id: str
         guild_id: str
         content: str
         id: str
-        mentions = [__MsgMentions]
-        attachments = [__MsgAttachments]
+        mentions = List[__MsgMentions]
+        attachments = List[__MsgAttachments]
         seq: int
         seq_in_channel: str
         timestamp: str
@@ -145,7 +149,7 @@ class Model:
         t: str
         event_id: str
 
-    class MESSAGE_DELETE:
+    class MESSAGE_DELETE(event_class):
         """
         消息撤回事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -158,7 +162,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#62779e66c4773b0012899efb
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#message-delete
         """
         class message:
             class author:
@@ -176,7 +180,7 @@ class Model:
         t: str
         event_id: str
 
-    class DIRECT_MESSAGE:
+    class DIRECT_MESSAGE(event_class):
         """
         私信消息事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -184,7 +188,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#62779fecc4773b0012899f05
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#direct-message
         """
         class __MsgAttachments:
             content_type: str
@@ -211,7 +215,7 @@ class Model:
         content: str
         direct_message: bool
         id: str
-        attachments = [__MsgAttachments]
+        attachments = List[__MsgAttachments]
         seq: int
         seq_in_channel: str
         src_guild_id: str
@@ -220,7 +224,7 @@ class Model:
         t: str
         event_id: str
 
-    class MESSAGE_AUDIT:
+    class MESSAGE_AUDIT(event_class):
         """
         主动消息审核事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -232,7 +236,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#6277a091c4773b0012899f10
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#message-audit
         """
         audit_id: str
         audit_time: str
@@ -243,7 +247,7 @@ class Model:
         t: str
         event_id: str
 
-    class FORUMS_EVENT:
+    class FORUMS_EVENT(event_class):
         """
         论坛事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -257,19 +261,19 @@ class Model:
             现有推送的type字段：
 
             - type 1 - 普通文本，子字段text
-            - type 2 - 图片，子字段image
-            - type 3 - 视频，子字段video
             - type 4 - url信息，子字段url
 
             现无推送，根据文档列出的type：
 
+            - 原新type 2 - 图片，子字段image（曾短暂出现，目前为空子字段，无任何内容反馈）
+            - 原新type 3 - 视频，子字段video（曾短暂出现，目前为空子字段，无任何内容反馈）
             - 原type 2 - at信息，目前为空子字段，无任何内容反馈
             - 原type 4 - 表情，目前为空子字段，无任何内容反馈
             - 原type 5 - #子频道，目前为空子字段，无任何内容反馈
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#6277a163c4773b0012899f14
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#forums-event
         """
 
         class thread_info:
@@ -281,10 +285,10 @@ class Model:
 
                         type: int
 
-                    elems: list[__ForumsSubTitle]
+                    elems: List[__ForumsSubTitle]
                     props: object
 
-                paragraphs: list[__ForumsTitle]
+                paragraphs: List[__ForumsTitle]
 
             class content:
                 class __ForumsContent:
@@ -292,24 +296,24 @@ class Model:
                         class text:  # type = 1
                             text: str
 
-                        class image:  # type = 2
-                            class plat_image:
-                                url: str
-                                width: int
-                                height: int
-                                image_id: str
-
-                        class video:  # type = 3
-                            class plat_video:
-                                class cover:
-                                    url: str
-                                    width: int
-                                    height: int
-
-                                url: str
-                                width: int
-                                height: int
-                                video_id: str
+#                         class image:  # type = 2
+#                             class plat_image:
+#                                 url: str
+#                                 width: int
+#                                 height: int
+#                                 image_id: str
+#
+#                         class video:  # type = 3
+#                             class plat_video:
+#                                 class cover:
+#                                     url: str
+#                                     width: int
+#                                     height: int
+#
+#                                 url: str
+#                                 width: int
+#                                 height: int
+#                                 video_id: str
 
                         class url:  # type = 4
                             url: str
@@ -317,10 +321,10 @@ class Model:
 
                         type = int
 
-                    elems: list[__ForumsSubContent]
+                    elems: List[__ForumsSubContent]
                     props: object
 
-                paragraphs: list[__ForumsContent]
+                paragraphs: List[__ForumsContent]
 
             thread_id: str
             date_time: str
@@ -331,7 +335,7 @@ class Model:
         t: str
         event_id: str
 
-    class AUDIO_ACTION:
+    class AUDIO_ACTION(event_class):
         """
         音频事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -345,7 +349,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#6277ba728e0a81001252e202
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#audio-action
         """
         channel_id: str
         guild_id: str
@@ -354,7 +358,7 @@ class Model:
         t: str
         event_id: str
 
-    class REACTION:
+    class REACTION(event_class):
         """
         表情表态事件的数据模型，可从t字段判断具体事件，其中包含：
 
@@ -363,7 +367,7 @@ class Model:
 
         .. seealso::
              其子字段数据可参阅：
-             https://thoughts.teambition.com/sharespace/6289c429eb27e90041a58b57/docs/6289c429eb27e90041a58b55#6277bb178e0a81001252e20a
+             https://qg-botsdk.readthedocs.io/zh_CN/latest/Model%E5%BA%93.html#reaction
         """
         class emoji:
             id: str
@@ -378,3 +382,24 @@ class Model:
         guild_id: str
         t: str
         event_id: str
+
+    class INTERACTION(event_class):
+        """
+
+        """
+        class data:
+            class resolved:
+                button_data: str
+                button_id: str
+                message_id: str
+                user_id: str
+            type: int
+
+        application_id: str
+        channel_id: str
+        guild_id: str
+        id: str
+        type: int
+        version: int
+        t: str
+        event_id: str
